<?php
namespace Zeedhi\ReportWebService\Controllers;

use Zeedhi\Framework\Controller\Simple;
use Zeedhi\ReportWebService\Services\Exception;
use Zeedhi\ReportWebService\Services\ReportReader as ReportService;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\ReportWebService\Services\ReportInfoManager;


/**
 * The main controller on the webservice.
 */
class ReportReader extends Simple{

    /** @var ReportService $reportService Service to build reports.*/
    protected $reportService;
    /** @var ReportInfoManager $reportInfoManager Service to manage the report info save on the session. */
    protected $reportInfoManager;

    /**
     * Constructor.
     *
     * @param ReportService $reportService Service to create, read and delete the report.
     * @param ReportInfoManager $reportInfoManager Service to get from the session the report info.
     */
    public function __construct(ReportService $reportService, ReportInfoManager $reportInfoManager){
        $this->reportService = $reportService;
        $this->reportInfoManager = $reportInfoManager;
    }

    /**
     * Reads the report.
     *
     * Reads the report from the request.
     *
     * @param Row $request The request with the report.
     * @throws \Zeedhi\ReportWebService\Services\Exception Returned when the given key does not has a report
     * registered.
     */
    public function readReport(Row $request) {
        $key = $request->getRow()['KEY'];
        $report = $this->reportInfoManager->getReportInfo($key);
        if(!$report){
            throw Exception::reportNotFound();
        }

        $this->reportService->printReport($report['fileName'], $report['title']);

        $this->reportService->deleteReport($report['fileName']);
        exit();
    }

}