<?php

namespace Zeedhi\ReportWebService\Services;

class ReportReader {


    /**
     * Constructor.
     *
     * @param $reportPath The path to the report
     */
    public function __construct($reportPath) {
        $this->reportPath = $reportPath;
    }


    /**
     * Retrieves the report path.
     *
     * Returns the full path of the report with the given name.
     *
     * @param $reportName The name of the report whose path will be retrieved.
     */
    protected function getReportPath($reportName) {
        return $this->reportPath.DIRECTORY_SEPARATOR.$reportName;
    }

    /**
     * Reads the file.
     *
     * calls the function readfile passing the given path.
     *
     * @param $reportPath The path to the report
     */
    protected function readFile($reportPath){
        readfile($reportPath);
    }

    /**
     * Configure the headers to read correctly the file.
     *
     * Set the file type and the name to be downloaded on the header.
     *
     * @param string $filePath Real name of the file that will be downloaded.
     * @param string $title Custom name of the file that will be downloaded.
     */
    protected function setHeaders($filePath, $title){
        $extension = pathinfo($filePath, PATHINFO_EXTENSION);
        $file = file($filePath);

        header("Content-type:application/$extension");
        header("Content-Disposition:inline;filename=$title.$extension");
    }


    /**
     * Prints the report from the file.
     *
     * Set the header of the file and prints it.
     *
     * @param $reportName The name of the report to be printed.
     */
    public function printReport($reportName, $title) {
        $reportPath = $this->getReportPath($reportName);
        $this->setHeaders($reportPath, $title);

        $this->readFile($reportPath);
    }


    /**
     * Deletes the report.
     *
     * Call the function unlink with the full path of the file with the given name.
     *
     * @param $reportName The name of the report to be deleted.
     */
    public function deleteReport($reportName) {
        $reportPath = $this->getReportPath($reportName);
        unlink($reportPath);
    }


}