<?php
namespace tests\Zeedhi\ReportWebService\Controllers;

use Zeedhi\ReportWebService\Controllers\Report as ReportController;
use Zeedhi\ReportWebService\Services\Report as ReportService;
use Zeedhi\ReportWebService\Services\ReportInfoManager;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Exception;
use Zeedhi\ReportWebService\Controllers\ReportGenerator;

class ReportTest extends \PHPUnit\Framework\TestCase {

    /**
     *  @var ReportService
     *  @var ReportController
     *  */
    protected $reportService;
    protected $reportController;
    protected $response;
    protected $request;
    private $reportInfoManager;
    protected $row = array(
        "dataSet" => array(
            array("COUNTRY_ID" => "FR", "COUNTRY_NAME" => "France", "REGION_NAME" => "Europa"),
            array("COUNTRY_ID" => "UK", "COUNTRY_NAME" => "United Kingdom", "REGION_NAME" => "Europa"),
            array("COUNTRY_ID" => "NL", "COUNTRY_NAME" => "Netherlands", "REGION_NAME" => "Europa"),
            array("COUNTRY_ID" => "IT", "COUNTRY_NAME" => "Italy", "REGION_NAME" => "Europa"),
            array("COUNTRY_ID" => "DK", "COUNTRY_NAME" => "Denmark", "REGION_NAME" => "Europa"),
            array("COUNTRY_ID" => "DE", "COUNTRY_NAME" => "Germany", "REGION_NAME" => "Europa"),
            array("COUNTRY_ID" => "CH", "COUNTRY_NAME" => "Switzerland", "REGION_NAME" => "Europa"),
            array("COUNTRY_ID" => "BE", "COUNTRY_NAME" => "Belgium", "REGION_NAME" => "Europa"),
            array("COUNTRY_ID" => "AR", "COUNTRY_NAME" => "Argentina", "REGION_NAME" => "America"),
            array("COUNTRY_ID" => "MX", "COUNTRY_NAME" => "Mexico", "REGION_NAME" => "America"),
            array("COUNTRY_ID" => "CA", "COUNTRY_NAME" => "Canada", "REGION_NAME" => "America"),
            array("COUNTRY_ID" => "US", "COUNTRY_NAME" => "United States of America", "REGION_NAME" => "America"),
            array("COUNTRY_ID" => "BR", "COUNTRY_NAME" => "Brasil", "REGION_NAME" => "America"),
            array("COUNTRY_ID" => "CN", "COUNTRY_NAME" => "China", "REGION_NAME" => "Asia"),
            array("COUNTRY_ID" => "HK", "COUNTRY_NAME" => "HongKong", "REGION_NAME" => "Asia"),
            array("COUNTRY_ID" => "SG", "COUNTRY_NAME" => "Singapore", "REGION_NAME" => "Asia"),
            array("COUNTRY_ID" => "IN", "COUNTRY_NAME" => "India", "REGION_NAME" => "Asia"),
            array("COUNTRY_ID" => "JP", "COUNTRY_NAME" => "Japan", "REGION_NAME" => "Asia"),
            array("COUNTRY_ID" => "AU", "COUNTRY_NAME" => "Australia", "REGION_NAME" => "Asia"),
            array("COUNTRY_ID" => "KW", "COUNTRY_NAME" => "Kuwait", "REGION_NAME" => "Middle East and Africa"),
            array("COUNTRY_ID" => "IL", "COUNTRY_NAME" => "Israel", "REGION_NAME" => "Middle East and Africa"),
            array("COUNTRY_ID" => "EG", "COUNTRY_NAME" => "Egypt", "REGION_NAME" => "Middle East and Africa"),
            array("COUNTRY_ID" => "NG", "COUNTRY_NAME" => "Nigeria", "REGION_NAME" => "Middle East and Africa"),
            array("COUNTRY_ID" => "AT", "COUNTRY_NAME" => "Austrália", "REGION_NAME" => "Oceania")
        ),
        "metaData" => array(
            "name"  => "countries_by_regions",
            "title" => "Contries by Regions",
            "reportName" => "countries_by_regions",
            "version" => "1.0a",
            "columns" => array(
                "COUNTRY_ID" => array(
                    "descricao" => "Id",
                    "size" => "20%",
                    "align" => "left",
                    "format" => null,
                ),
                "COUNTRY_NAME" => array(
                    "descricao" => "Country Name",
                    "size" => "50%",
                    "align" => "left",
                    "format" => null,
                ),
                "REGION_NAME" => array(
                    "descricao" => "Region Name",
                    "size" => "30%",
                    "align" => "left",
                    "format" => null,
                ),
            ),
            "groups" => array(
                array(
                    "name"   => "group_by_region",
                    "field"  => "REGION_NAME",
                    "header" => array(
                        "label"        => "Region",
                        "displayfield" => "REGION_NAME",
                    ),
                    "footer" => array(
                        "label"      => "Countries in region",
                        "expression" => "COUNT(*)"
                    )
                )
            ),
            "reportSummary" => array(
                "label"      => "Total of countries",
                "expression" => "COUNT(*)"
            ),
            'clientLogo' => 'http://localhost/static/images/logo/logo-cliente.gif',
            'enterpriseLogo' => 'http://localhost/static/images/zeedhi-logo-min.png',
            'productLogo' => 'http://localhost/static/images/zeedhi-logo.png'
        ),
        "filter" => []
    );

    public function setUp() {
        $this->reportInfoManager = $this->getMockBuilder(ReportInfoManager::class)
            ->disableOriginalConstructor()
            ->getMock();
        $this->reportService = new ReportService(realpath(__DIR__."/reports/"));
        $this->reportController = new ReportGenerator($this->reportService, $this->reportInfoManager);
        $this->response = new Response();
    }

    public function testGenerateReport() {
        $this->row = array(
            'dataSet' => json_encode($this->row['dataSet']),
            'metaData' => json_encode($this->row['metaData']),
            'filter' => json_encode($this->row['filter'])
        );
        $this->request = $this->getMockBuilder(SomeClass::class)
                              ->setMethods(array("getRow"))
                              ->getMock();
        $row = new Row($this->row, $this->request, "", 1);
        $this->reportController->generatePDF($row, $this->response);
    }

    public function testGenerateReportError(){
        $this->row = array(
            'dataSet' => json_encode(array("name" => "errorTest")),
            'metaData' => json_encode(array("name" => "errorTest")),
            'filter' => json_encode(array("name" => "errorTest"))
        );
        $this->request = $this->getMockBuilder(SomeClass::class)
                              ->setMethods(array("getRow"))
                              ->getMock();
        $row = new Row($this->row, $this->request, "", 1);
        $this->reportController->generatePDF($row, $this->response);
        $this->assertEmpty($this->response->getMessages());
    }


}
