<?php
namespace tests\Zeedhi\ReportWebService\SpreadSheet;

use Zeedhi\ReportWebService\SpreadSheet\XLSXWriter;

class XLSXWriterTest extends \PHPUnit\Framework\TestCase {

    /** @var XLSXWriter */
    protected $xlsxWriter;

    protected function setUp() {
        $this->xlsxWriter = new XLSXWriter(realpath(__DIR__."/reports/"));

        $this->data = [
            ["CODE","EMPLOYEE_NAME","SALARY"],
            ["1","Alexander",7000,],
            ["1.1","Alberto",12000,],
            ["1.1.1","Allan",9000,],
            ["2","Alyssa",8800,],
            ["2.1","Alana",3100,]
        ];

        $this->metadata = [
                "reportName" => "report",
                "columns" => [
                "CODE" => [
                    'description' => 'Code',
                    'format' => [
                            'type' => 'number',
                            'params' => ['precision' => 2]
                        ]
                    ],
                    "EMPLOYEE_NAME" => [
                        'description' => 'Employee_name',
                        'format' => ['type' => 'float']
                    ],
                    "SALARY"        => ['description' => 'Salary']
                ],
                "xlsDefaultType" => 'default'
        ];
    }

    public function testGenerateXLS() {
        $fileName = $this->xlsxWriter->generateXLS($this->data, $this->metadata);

        $filename = __DIR__ . "/reports/" . $fileName;
        $this->assertTrue(file_exists($filename));
        $this->assertTrue(unlink($filename));
    }

    public function testGenerateXLSWithEmptyHeader() {
        $this->metadata = ["reportName"=>"xlsWithEmptyHeader", "columns" => [
            "CODE" => ['description' => 'Code'],
            "EMPLOYEE_NAME" => ['description' => 'Employee_name' ],
            "SALARY" => ['description' => 'Salary']
        ]];
        $fileName = $this->xlsxWriter->generateXLS($this->data, $this->metadata);

        $filename = __DIR__ . "/reports/" . $fileName;
        $this->assertTrue(file_exists($filename));
        $this->assertTrue(unlink($filename));
    }

    public function testGenerateXLSWithNoDescription() {
        $this->metadata = ["reportName"=>"xlsWithEmptyHeader", "columns" => [
            "CODE" => [],
            "EMPLOYEE_NAME" => ['description' => 'Employee_name' ],
            "SALARY" => ['description' => 'Salary']
        ]];
        $fileName = $this->xlsxWriter->generateXLS($this->data, $this->metadata);

        $filename = __DIR__ . "/reports/" . $fileName;
        $this->assertTrue(file_exists($filename));
        $this->assertTrue(unlink($filename));
    }

}
